==> ulyxex.1.5.3.6.with-tinyMce.zip: pages/admin_page_modify.php <==
<?php
/* Ulyxex version 1.5.3.6 *****************/
if (!isset($admin)) exit("not in admin !");
require_once("core/admin_page_modify.php");
/****************************************/
/* page vars							*/
/* check post 							*/
$pageId = isset($_GET['page'])?$h->num($_GET['page']):$h->num($_POST['page']);
/****************************************/
/* page elements						*/
$o_pag = new PageModify($pageId);
$o_pag->level(2);

$userInfos = $o_pag->user_params($_SESSION['userid']);
if ($_SESSION['level'] > 1){
/* check if user own the page level */
	$pageDat = $o_pag->page_params($pageId);
	if ($pageDat['USERID'] != $userInfos['ID']) exit("you can't modify this page !");
}
$css = $h->css("css/".ADMINCSS,"external");
$meta = $h->meta("Content-Type","text/html; charset=UTF-8");
$meta .= $h->meta("viewport","width=device-width, initial-scale=1.0","name");
$title = $h->title($t->wr("modify page of").$userInfos['USERNAME']);
$scripts = $h->script("js/tinymce/tinymce.min.js","external").$h->script("js/tinymce.js","external"); // if script tinyMce
$head = $h->head($meta.$css.$scripts.$title);

$topPage = $h->h1($t->wr("modify page of").$h->span($userInfos['USERNAME'],"class='username'"));
$topPage .= $h->h2($adminNavigation->links);

$bottomPage = $h->ulyxCredits($firstLine=False);
/****************************************/
/* page data							*/	
$data = isset($_POST['update'])?$o_pag->update_page():"";

$data .= $o_pag->data_page();
/****************************************/
/* show									*/
$bottomPage .= $h->countQ();
$body = $h->body($topPage.$data.$bottomPage);
$page = $h->html($head.$body);

echo $page;
?>

==> ulyxex.1.5.4.0.with-tinyMce.zip: pages/admin_page_modify.php <==
<?php
/* Ulyxex version 1.5.4.0 ***************/
/* code http://ulyxex.logz.org **********/
/* Andre Lozano http://andre-lozano.org */
if (!isset($admin)) exit("not in admin !");
require_once("core/admin_page_modify.php");
/****************************************/
/* page vars							*/
/* check post 							*/
$pageId = isset($_GET['page'])?$h->num($_GET['page']):$h->num($_POST['page']);
/****************************************/
/* page elements						*/
$o_pag = new PageModify($pageId);
$o_pag->level(2);

$userInfos = $o_pag->user_params($_SESSION['userid']);
if ($_SESSION['level'] > 1){
/* check if user own the page level */
	$pageDat = $o_pag->page_params($pageId);
	if ($pageDat['USERID'] != $userInfos['ID']) exit("you can't modify this page !");
}
$css = $h->css("css/".ADMINCSS,"external");
$ico = $h->ico("favicon.png");
$meta = $h->meta("Content-Type","text/html; charset=UTF-8");
$meta .= $h->meta("viewport","width=device-width, initial-scale=1.0","name");
$title = $h->title($t->wr("modify page of").$userInfos['USERNAME']);
$scripts = $h->script("js/tinymce/tinymce.min.js","external").$h->script("js/tinymce.js","external"); // if script tinyMce
$head = $h->head($ico.$meta.$css.$scripts.$title);

$topPage = $h->h1($t->wr("modify page of").$h->span($userInfos['USERNAME'],"class='username'"));
$topPage .= $h->h2($adminNavigation->links);

$bottomPage = $h->ulyxCredits($firstLine=False);
/****************************************/
/* page data							*/	
$data = isset($_POST['update'])?$o_pag->update_page():"";

$data .= $o_pag->data_page();
/****************************************/
/* show									*/
$bottomPage .= $h->countQ();
$body = $h->body($topPage.$data.$bottomPage);
$page = $h->html($head.$body);

echo $page;
?>
